Learn R Programming

RBaM (version 1.1.1)

addQuotes: Add double quotes to a string or to each element of a string vector

Description

Add double quotes to a string or to each element of a string vector

Usage

addQuotes(txt)

Value

The double-quoted character vector

Arguments

txt

Character vector