Learn R Programming

RBaM (version 1.1.1)

checkFormula: Check a formula make sense within a given namespace

Description

Check a formula make sense within a given namespace

Usage

checkFormula(f, namespace)

Value

A list with the following fields:

ok

Does the formula make sense?

mess

message

Arguments

f

Character string, formula

namespace

Character vector, namespace (i.e. names of known variables)