- X
data frame, observed input variables.
- Y
data frame, observed output variables (same number of rows as X).
- data.dir
Character, directory where a copy of the dataset will be
written if required. Default is the current working directory, but you
may prefer to use the BaM workspace.
- data.fname
Character, data file name.
- fname
Character, configuration file name.
- Xu
data frame, random uncertainty in X, expressed as a standard deviation.
Same dimension as X.
- Xb
data frame, systematic uncertainty in X, expressed as a standard deviation.
Same dimension as X.
- Xb.indx
data frame, index of systematic errors in X.
Same dimension as X.
- Yu
data frame, random uncertainty in Y, expressed as a standard deviation.
Same dimension as Y.
- Yb
data frame, systematic uncertainty in Y, expressed as a standard deviation.
Same dimension as Y.
- Yb.indx
data frame, index of systematic errors in Y.
Same dimension as Y.
- VAR.indx
data frame, indices used for defining how VAR parameters vary.