Learn R Programming

RBaM (version 1.1.1)

downloadBaM: BaM downloader

Description

Download BaM executable

Usage

downloadBaM(
  destFolder,
  url = NULL,
  os = Sys.info()["sysname"],
  quiet = FALSE,
  ...
)

Value

nothing - just download the file.

Arguments

destFolder

character string, folder where BaM executable will be downloaded.

url

character string, the url from which BaM should be downloaded. When NULL, the url is determined automatically by using GitHub API to determine the latest release and the file corresponding to the OS.

os

character string, operating system, e.g. 'Linux', 'Windows' or 'Darwin'.

quiet

logical, if TRUE, suppress status messages.

...

arguments passed to function `download.file`

Examples

Run this code
  try(downloadBaM(destFolder=tempdir()))

Run the code above in your browser using DataLab