Learn R Programming

RBaM (version 1.1.1)

getInitPar: Get initial values

Description

Get the initial values of a list of parameters and return them as a vector.

Usage

getInitPar(parameters)

Value

A numeric vector containing the initial values

Arguments

parameters

List of parameter objects, parameters whose initial values are sought.

Examples

Run this code
ps <- list(parameter(name='par1',init=0),parameter(name='par2',init=1))
getInitPar(ps)

Run the code above in your browser using DataLab