powered by
Computes the log-likelihood from model-simulated values, based on a Gaussian iid error model:
Yobs = Ysim + delta + epsilon
Measurement errors: delta~ N(0,sdev=Yu)
Structural errors: epsilon~ N(0,sdev=gamma)
If Yobs/Ysim are multi-variate, this error model is applied independently to each component.
llfunk_iid_Gaussian(Ysim, Yobs, Yu, gamma)
A numeric value equal to the log-likelihood.
data frame, model-simulated values.
data frame, corresponding observed values, same dimensions as Ysim. NAs are skipped.
data frame, measurement uncertainties (standard deviations), same dimensions as Ysim and Yobs.
numeric vector, structural error parameters. length(gamma) = number of columns in Ysim.
Yobs=SauzeGaugings['Q'] Yu=SauzeGaugings['uQ'] Ysim=100*(SauzeGaugings['H']+0.5)^1.6 llfunk_iid_Gaussian(Ysim,Yobs,Yu,gamma=100)
Run the code above in your browser using DataLab