Creates a new instance of a 'mcmcOptions' object
mcmcOptions(
fname = "Config_MCMC.txt",
result.fname = "Results_MCMC.txt",
nAdapt = 100,
nCycles = 100,
minMoveRate = 0.1,
maxMoveRate = 0.5,
downMult = 0.9,
upMult = 1.1,
multFactor = 0.1,
manualMode = FALSE,
thetaStd = 9999,
gammaStd = list(9999)
)An object of class 'mcmcOptions'.
Character, configuration file name.
Character, result file name.
Integer, adaptation period: jump sizes are increased/decreased every Nadapt iterations to comply with the desired moving rates.
Integer, number of adaptation cycles (total number of iterations is hence Nadapt * Ncycles).
Numeric in (0;1), lower bound for the desired move rate interval.
Numeric in (0;1), upper bound for the desired move rate interval.
Numeric in (0:1), multiplication factor used to decrease jump size when move rate is too low.
Numeric (>1, avoid 1/dowMult) multiplication factor used to increase jump size when move rate is too high.
Numeric >0, multiplicative factor to set initial jump standard deviations to multFactor*|initValue| (AUTO mode).
logical, should jump standard deviations be entered manually?
Numeric vector (>0), jump standard deviations for model parameters theta (MANUAL mode).
list of numeric vectors (>0), size = number of output variables of the model. Jump standard deviations for structural error parameters gamma of each output variable (MANUAL mode).