Learn R Programming

RBaM (version 1.1.1)

setInitPar: Set initial values

Description

Set the initial values of a list of parameters.

Usage

setInitPar(parameters, values)

Value

a list of parameter objects equal to the input list 'parameters', except for their initial values.

Arguments

parameters

List of parameter objects, parameters whose initial values are to be set.

values

Numeric vector, initial values.

Examples

Run this code
ps <- list(parameter(name='par1',init=0),parameter(name='par2',init=1))
ps=setInitPar(ps,c(10,100))
print(ps)

Run the code above in your browser using DataLab