Size of two populations of the same species put in two different environments, as a function of time and local temperature.
Input variables: time t, temperature at site 1 T1, temperature at site 2 T2.
Output variables: population size at site 1 P1, population size at site 2 P2.
Data are synthetically generated from a logistic model.
twoPopulationsAn object of class data.frame with 101 rows and 5 columns.