- logPdf
function, evaluating the log-density of the distribution to sample from (up to a proportionality constant).
logPdf can return either a single numeric value, interpreted as the target log-pdf,
or a list containing components named 'logPosterior', 'logLikelihood' and 'logPrior'.
- x0
numeric vector, starting point.
- s0
numeric vector, starting jump standard deviations.
- nTheta
integer>0, size of the "theta" part of x0, i.e. components that represent the
model parameters rather than structural errors parameters (gamma).
This is used to speed-up the sampler by avoiding running the model for gamma components.
nTheta=length(x0) (default) implies no attempt at speeding up.
- nAdapt
integer > 1, number of iterations before adapting the jump standard deviations.
- nCycles
integer > 1, number of adaption cycles. Total number of iterations is hence equal to nAdapt*nCycles.
nCycles=1 leads to a non-adaptive one-at-a-time Metropolis sampler.
- minMoveRate
numeric in (0;1), lower bound for the desired move rate interval.
- maxMoveRate
numeric in (0;1), upper bound for the desired move rate interval.
- downMult
numeric in (0;1), multiplication factor used to decrease the jump standard deviation when move rate is too low.
- upMult
numeric (>1, avoid 1/downMult) multiplication factor used to increase the jump standard deviations when move rate is too high.
- ...
other arguments passed to function logPdf