powered by
Get the initial values of a list of parameters and return them as a vector.
getInitPar(parameters)
A numeric vector containing the initial values
List of parameter objects, parameters whose initial values are sought.
ps <- list(parameter(name='par1',init=0),parameter(name='par2',init=1)) getInitPar(ps)
Run the code above in your browser using DataLab