If Yobs/Ysim are multi-variate, this error model is applied independently to each component.
Usage
llfunk_iLinear_Gaussian(Ysim, Yobs, Yu, gamma)
Value
A numeric value equal to the log-likelihood.
Arguments
Ysim
data frame, model-simulated values.
Yobs
data frame, corresponding observed values, same dimensions as Ysim. NAs are skipped.
Yu
data frame, measurement uncertainties (standard deviations), same dimensions as Ysim and Yobs.
gamma
numeric vector, structural error parameters, organized as:
gamma=c((g1,g2) for the 1st component of Ysim,(g1,g2) for the 2nd component of Ysim, etc.)
=> length(gamma) = 2*(number of columns in Ysim).