powered by
Set the initial values of a list of parameters.
setInitPar(parameters, values)
a list of parameter objects equal to the input list 'parameters', except for their initial values.
List of parameter objects, parameters whose initial values are to be set.
Numeric vector, initial values.
ps <- list(parameter(name='par1',init=0),parameter(name='par2',init=1)) ps=setInitPar(ps,c(10,100)) print(ps)
Run the code above in your browser using DataLab